@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: build_boilerplate.py 10213 2017-08-22 09:34:20Z Lavender $
+# $Id: build_boilerplate.py 10302 2017-09-17 10:06:27Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-08-22 17:34:20 +0800 (週二, 22 八月 2017) $
-# $Revision: 10213 $
+# $Date: 2017-09-17 18:06:27 +0800 (週日, 17 九月 2017) $
+# $Revision: 10302 $
 
 import os
 import sys
@@ -28,9 +28,9 @@ from django.template.loader import get_template
 
 from Zephyrus.boilerplate.management.commands import (
     TEMPLATES_DIR_PATH, STATIC_DIR_PATH)
-from Zephyrus.boilerplate.management.commands import createLogger
+from Zephyrus.boilerplate.management.commands import cerateLogger
 
-logger = createLogger(__name__, "BuildBoilerplate.log")
+logger = cerateLogger(__name__, "BuildBoilerplate.log")
 
 # inside
 TEXT_TAGS = ['h1', 'h2', 'h3', 'h4', 'h5', 'h6', 'p', 'button',]
@@ -108,7 +108,7 @@ class Command(BaseCommand):
 
                     page = parse(f)
 
-                    tags = ALL_INSIDE_TAGS + ALL_OUTSIDE_TAGS + BLOCK_TAGS
+                    tags = BLOCK_TAGS + ALL_INSIDE_TAGS + ALL_OUTSIDE_TAGS
                     tags = self.clearTags(tags)
 
                     for tag in tags:
@@ -120,7 +120,7 @@ class Command(BaseCommand):
                     self.replaceKeyword(page, fileDict)
                     idDict = self.buildImgIdDict(page, name)
 
-                    page.write(file, method='html')
+                    page.write(file, method='html', pretty_print=True)
                 # end process lxml etree
 
                 # start endprocess
@@ -220,8 +220,6 @@ class Command(BaseCommand):
 
     def addOutsidePlaceholder(self, id, ele):
         if ele.tail:
-            if ele.tail == "{% endplaceholder %}":
-                return
             ele.tail = "{% endplaceholder %}" + ele.tail
         else:
             ele.tail = "{% endplaceholder %}"
@@ -250,18 +248,26 @@ class Command(BaseCommand):
                                 "{% placeholder " + "'%s' " % id + "or %}"
 
     def addDivPlaceholder(self, id, ele):
-        context = etree.tostring(ele, pretty_print=True)
-
-        if not context.startswith("<div>{% placeholder "):
-            if not ele.getchildren():
-                if ele.text is not None:
-                    
-                    if ele.text.strip() is '':
-                        return
+        addInside = True
+        for child in ele.getchildren():
+            if child.tag == 'div' or child.tag == 'img':
+                addInside = False
 
+        if addInside:
+            if not ele.text == None:
+                if not ele.text.strip() == '':
                     self.addInsidePlaceholder(id, ele)
-                else:
-                    ele.text = ''
+        else:
+            index = 1
+            if not ele.text == None:
+                if not ele.text.strip() == '':
+                    ele.text = "{% placeholder " + "'%s-text%d' " % (id, index) + "or %}" + ele.text + "{% endplaceholder %}"
+
+            for child in ele.getchildren():
+                if not child.tail == None:
+                    if not child.tail.strip() == '':
+                        index += 1
+                        child.tail = "{% placeholder " + "'%s-text%d' " % (id, index) + "or %}" + child.tail + "{% endplaceholder %}"
 
     def addCMSTags(self, page):
         for tag in page.iter(tag='head'):
