@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: setup.py 10199 2017-08-20 02:22:54Z Lavender $
+# $Id: setup.py 10301 2017-09-17 08:17:11Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-08-20 10:22:54 +0800 (週日, 20 八月 2017) $
-# $Revision: 10199 $ 
+# $Date: 2017-09-17 16:17:11 +0800 (週日, 17 九月 2017) $
+# $Revision: 10301 $ 
 
 import os
 import sys
@@ -35,7 +35,16 @@ handler.setFormatter(
 logger.addHandler(handler)
 
 def copyToPath(baseDir, templateDir, staticDir, mode):
+    if not templateDir:
+        templateDir = os.path.join(baseDir, 'templates')
+    if not staticDir:
+        staticDir = os.path.join(baseDir,'static')
+        
     logger.info("-----Start copy templates-----")
+    if not os.path.exists(staticDir):
+        os.mkdir(staticDir)
+    if not os.path.exists(templateDir):
+        os.mkdir(templateDir)
     for root, dirs, files in os.walk(os.path.join(SETUP_DIR, "static")):
         for d in dirs:
             index = os.path.join(root, d).index("static") + len("static/")
@@ -87,7 +96,7 @@ def findSettings(path):
             if f == 'settings.py':
                 return os.path.join(root, f)
                 
-def writeSettings(settingsPath, templateDir):
+def writeSettings(settingsPath, templateDir, staticDir, hasCmsTemplate):
     logger.info("-----Start write and backup settings.py-----")
     def getCMSTemplates():
         templates = []
@@ -116,13 +125,38 @@ def writeSettings(settingsPath, templateDir):
     shutil.copyfile(settingsPath, bak)
     logger.info("Succeed to backup settings.py to %s." % bak)
                 
+    with open(settingsPath, 'r') as settings:
+        content = settings.read()
                 
-    with open(settingsPath, 'a+') as settings:
-        content = \
+    with open(settingsPath, 'w') as settings:    
+        if hasCmsTemplate:
+            content += \
 '''
 CMS_TEMPLATES = list(CMS_TEMPLATES)
 CMS_TEMPLATES += %s
 ''' % str(getCMSTemplates())
+        else:
+            content += \
+'''
+CMS_TEMPLATES = %s
+''' % str(getCMSTemplates())
+
+        if not templateDir:
+            content = content.replace(
+                "'DIRS': []", "'DIRS': [os.path.join(BASE_DIR, 'templates'),]")
+            
+        if not staticDir:
+            content += \
+'''
+if DEBUG:
+    STATICFILES_DIRS = (
+        os.path.join(BASE_DIR, 'static'),
+    )
+else:
+    STATIC_ROOT = os.path.join(
+        os.path.dirname(os.path.dirname(__file__)), 'static')
+'''
+        
         settings.write(content)
     logger.info("Succeed to write settings.py")
               
@@ -173,15 +207,24 @@ if __name__ == "__main__":
     from django.conf import settings
     os.chdir(args.path)
     
-    templateDir = settings.TEMPLATES[0]['DIRS'][0]
-    staticDir = settings.STATIC_ROOT
+    try:
+        templateDir = settings.TEMPLATES[0]['DIRS'][0]
+    except Exception as e:
+        templateDir = None
     
-    if hasattr(settings, "STATICFILES_DIRS"):
+    try:
         staticDir = settings.STATICFILES_DIRS[0]
+    except Exception as e:
+        staticDir = None
     
     copyToPath(args.path, templateDir, staticDir, mode)
     
-    writeSettings(settingsPath, templateDir)
+    if hasattr(settings, "CMS_TEMPLATES"):
+        hasCmsTemplate = True
+    else:
+        hasCmsTemplate = False
+        
+    writeSettings(settingsPath, templateDir, staticDir, hasCmsTemplate)
     loadData(settings.LANGUAGE_CODE)
     
     
\ No newline at end of file
